#!/env/python3
#
#  Usage: python3 create_sols.py ../../api-tests/   <commit-or-tag>
#

import os
import sys
import csv

from robot.api import TestSuiteBuilder

import testspec
import config
import lib


def is_interface_heading(ref):
    return ref.lvl() == 3


def is_endpoint_heading(ref):
    return ref.lvl() == 4

def create_test_for_sol(solspec, all_tests_root, commit_id, output_dir):

    indexes = {
        "SOL002" : 'sol_002_index.csv',
        "SOL003" : 'sol_003_index.csv',
        "SOL005" : 'sol_005_index.csv',
    }

    templates = {
        "SOL002" : 'Tests-SOL002-VeVnfm_template.docx',
        "SOL003" : 'Tests-SOL003-OrVnfm_template.docx',
        "SOL005" : 'Tests-SOL005-OsMaNfvo_template.docx'
    }

    outnames = {
        "SOL002" : 'Tests-SOL002-VeVnfm.docx',
        "SOL003" : 'Tests-SOL003-OrVnfm.docx',
        "SOL005" : 'Tests-SOL005-OsMaNfvo.docx',
    }

    if not solspec in indexes:
        print("Error: Wrong SOL Specification: {}".format(solspec))
        return

    sol_index = None

    myf = open(indexes[solspec], 'r')
    sol_index = csv.reader(myf)

    if sol_index is None:
        print("ERROR OPENING INDEX: {}".format(indexes[solspec]))
        return

    spec = testspec.TestSpec(templates[solspec])
    current_folder = None

    for row in sol_index:
        if len(row) < 3:
            continue

        ref = lib.DocReference.from_str(row[0].strip())

        if is_interface_heading(ref):
            spec.add_heading_from_ref(row[1].strip(), ref)
            current_folder = row[2].strip()

        elif is_endpoint_heading(ref):
            suite = TestSuiteBuilder().build(
                os.path.join(all_tests_root, solspec, current_folder, row[2].strip())
            )
            lib.gen_api_suite(ref, suite, spec, current_folder, commit_id, solspec)

    outfn = os.path.join(output_dir,outnames[solspec])
    print("Writing {} definitions to: {}".format(solspec, outfn))
    spec.save(outfn)

if __name__ == "__main__":

    if len(sys.argv) < 2:
        print("Usage: robot2doc <sol_robot_root_dir> <commit-id>")
        sys.exit(-1)

    ROOT = sys.argv[1]
    COMMIT_ID = sys.argv[2] if len(sys.argv) > 2 else None

    print("Received arguments: ", sys.argv)

    print("Generating entire SOL tests")

    sol_specs = ["SOL002", "SOL003", "SOL005"]

    for solspec in sol_specs:
        create_test_for_sol(solspec, ROOT, COMMIT_ID, "..")

